@@ -169,7 +169,7 @@ class CommonTsetlinMachine():
 			if len(X.shape) == 3:
 				self.dim = (X.shape[1], X.shape[2],  1)
 			elif len(X.shape) == 4:
-				self.dim = X.shape
+				self.dim = X.shape[1:]
 
 			if self.append_negated:
 				self.number_of_features = int(self.patch_dim[0]*self.patch_dim[1]*self.dim[2] + (self.dim[0] - self.patch_dim[0]) + (self.dim[1] - self.patch_dim[1]))*2
@@ -222,7 +222,7 @@ class CommonTsetlinMachine():
 
 		for epoch in range(epochs):
 			for e in range(0, number_of_examples, batch_size):
-				self.update.prepared_call((16*13,1,1), (128,1,1), g.state, self.ta_state_gpu, self.clause_weights_gpu, self.class_sum_gpu, self.clause_output_gpu, self.clause_patch_gpu, self.encoded_X_training_gpu, self.Y_gpu, np.int32(e))
+				self.update.prepared_call(self.grid, self.block, g.state, self.ta_state_gpu, self.clause_weights_gpu, self.class_sum_gpu, self.clause_output_gpu, self.clause_patch_gpu, self.encoded_X_training_gpu, self.Y_gpu, np.int32(e))
 				cuda.Context.synchronize()
 
 		self.ta_state = np.array([])
@@ -274,6 +274,10 @@ class CommonTsetlinMachine():
 		return class_sum
 	
 class MultiClassConvolutionalTsetlinMachine2D(CommonTsetlinMachine):
+	"""
+	This class ...
+	"""
+	
 	def __init__(self, number_of_clauses, T, s, patch_dim, boost_true_positive_feedback=1, number_of_state_bits=8, append_negated=True, max_weight=1, grid=(16*13,1,1), block=(128,1,1)):
 		super().__init__(number_of_clauses, T, s, boost_true_positive_feedback=boost_true_positive_feedback, number_of_state_bits=number_of_state_bits, append_negated=append_negated, max_weight=max_weight, grid=grid, block=block)
 		self.patch_dim = patch_dim
@@ -340,7 +344,7 @@ class TsetlinMachine(CommonTsetlinMachine):
 		self.max_y = None
 		self.min_y = None
 		
-		encoded_Y = np.where(Y == 1, self.T, -self.T).as_type(np.int32)
+		encoded_Y = np.where(Y == 1, self.T, -self.T).astype(np.int32)
 
 		self._fit(X, encoded_Y, epochs = epochs, incremental = incremental, batch_size = batch_size)
 
